aboutsummaryrefslogtreecommitdiff
path: root/internal/game/render_combat.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/game/render_combat.go')
-rw-r--r--internal/game/render_combat.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/internal/game/render_combat.go b/internal/game/render_combat.go
index 7285ce7..c3c594c 100644
--- a/internal/game/render_combat.go
+++ b/internal/game/render_combat.go
@@ -6,8 +6,8 @@ import (
)
// renderBar is the shared bar renderer for both HP bars and task-progress bars.
// lowColor is the color used when the value falls below 40% (160 red for HP,
// 39 cyan for progress).
func (g *Game) renderBar(sess *net.Session, current, max, lowColor int) string {
if max <= 0 {
max = 1
@@ -23,19 +23,19 @@ func (g *Game) renderBar(sess *net.Session, current, max, lowColor int) string {
var fgColor int
switch {
case pct >= 70:
- fgColor = 82
+ fgColor = 108
case pct >= 40:
- fgColor = 220
+ fgColor = 179
default:
fgColor = lowColor
}
unicode := sess.Player != nil && sess.Player.OptionBool("unicode")
- style := &ui.BarStyle{FilledColor: fgColor, EmptyColor: 238, EmptyDim: true}
+ style := &ui.BarStyle{FilledColor: fgColor, EmptyColor: 237, EmptyDim: true}
bar := ui.RenderColoredBar(current, max, 10, unicode, style, g.colorMode(sess))
return "[" + bar + "]"
}
func (g *Game) hpBar(sess *net.Session, current, max int) string {
- return g.renderBar(sess, current, max, 160)
+ return g.renderBar(sess, current, max, 167)
}
@@ -6,8 +6,8 @@ import (
)
// renderBar is the shared bar renderer for both HP bars and task-progress bars.
-// lowColor is the color used when the value falls below 40% (160 red for HP,
-// 39 cyan for progress).
+// lowColor is the color used when the value falls below 40% (167 dusty red for
+// HP, 67 steel blue for progress) -- both palette colors.
func (g *Game) renderBar(sess *net.Session, current, max, lowColor int) string {
if max <= 0 {